<?php

/**
 * @file
 * Contains \Drupal\aggregator\Plugin\views\field\TitleLink.
 */

namespace Drupal\aggregator\Plugin\views\field;

use Drupal\views\Plugin\views\display\DisplayPluginBase;
use Drupal\views\Plugin\views\field\FieldPluginBase;
use Drupal\views\ViewExecutable;
use Drupal\Component\Annotation\PluginID;

/**
 * Defines a field handler that turns an item's title into a clickable link to
 * the original source article.
 *
 * @ingroup views_field_handlers
 *
 * @PluginID("aggregator_title_link")
 */
class TitleLink extends FieldPluginBase {

  /**
   * {@inheritdoc}
   */
  public function init(ViewExecutable $view, DisplayPluginBase $display, array &$options = NULL) {
    parent::init($view, $display, $options);

    $this->additional_fields['link'] = 'link';
  }

  /**
   * {@inheritdoc}
   */
  protected function defineOptions() {
    $options = parent::defineOptions();

    $options['display_as_link'] = array('default' => TRUE);

    return $options;
  }

  /**
   * {@inheritdoc}
   */
  public function buildOptionsForm(&$form, &$form_state) {
    $form['display_as_link'] = array(
      '#title' => t('Display as link'),
      '#type' => 'checkbox',
      '#default_value' => !empty($this->options['display_as_link']),
    );
    parent::buildOptionsForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  function render($values) {
    $value = $this->getValue($values);
    return $this->render_link($this->sanitizeValue($value), $values);
  }

  /**
   * Renders aggregator item's title as link.
   *
   * @param string $data
   *   The XSS safe string for the link text.
   * @param object $values
   *   The values retrieved from the database.
   *
   * @return data
   *   Returns string for the link text.
   */
  protected function render_link($data, $values) {
    $link = $this->getValue($values, 'link');
    if (!empty($this->options['display_as_link'])) {
      $this->options['alter']['make_link'] = TRUE;
      $this->options['alter']['path'] = $link;
      $this->options['alter']['html'] = TRUE;
      $this->options['alter']['absolute'] = TRUE;
    }

    return $data;
  }

}
